@@ -708,7 +708,7 @@ int main()
 
             cout << endl << "OK" << endl;
         }
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         cout << "\nCaught an exception: " << x.getMesg() << endl;
     } 
 
