@@ -180,7 +180,7 @@ try {
 
    cerr << "ok " << endl;
 
-} catch (AipsError x) {
+} catch (AipsError& x) {
    cerr << "aipserror: error " << x.getMesg() << endl;
    return 1;
 }
