@@ -65,7 +65,7 @@ void testVectorROIter (const Lattice<Int>& lattice, Bool useRef)
         Matrix<Int> temp(iter.matrixCursor());
         throw(AipsError("tHDF5Iterator - "
                         "matrixCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("two non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -74,7 +74,7 @@ void testVectorROIter (const Lattice<Int>& lattice, Bool useRef)
         Cube<Int> temp(iter.cubeCursor());
         throw(AipsError("tHDF5Iterator - "
                         "cubeCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("three non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -129,7 +129,7 @@ void testMatrixROIter (const Lattice<Int>& lattice, Bool useRef)
         Vector<Int> temp(iter.vectorCursor());
         throw(AipsError("tHDF5Iterator - "
                         "vectorCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("one non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -138,7 +138,7 @@ void testMatrixROIter (const Lattice<Int>& lattice, Bool useRef)
         Cube<Int> temp(iter.cubeCursor());
         throw(AipsError("tHDF5Iterator - "
                         "cubeCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("three non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -194,7 +194,7 @@ void testCubeROIter (const Lattice<Int>& lattice, Bool useRef)
         Vector<Int> temp(iter.vectorCursor());
         throw(AipsError("tHDF5Iterator - "
                         "vectorCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("one non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -203,7 +203,7 @@ void testCubeROIter (const Lattice<Int>& lattice, Bool useRef)
         Matrix<Int> temp(iter.matrixCursor());
         throw(AipsError("tHDF5Iterator - "
                         "matrixCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("two non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -253,7 +253,7 @@ void testArrayROIter (const Lattice<Int>& lattice, Bool useRef)
         Vector<Int> temp(iter.vectorCursor());
         throw(AipsError("tHDF5Iterator - "
                         "vectorCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("one non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -262,7 +262,7 @@ void testArrayROIter (const Lattice<Int>& lattice, Bool useRef)
         Matrix<Int> temp(iter.matrixCursor());
         throw(AipsError("tHDF5Iterator - "
                         "matrixCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("two non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -271,7 +271,7 @@ void testArrayROIter (const Lattice<Int>& lattice, Bool useRef)
         Cube<Int> temp(iter.cubeCursor());
         throw(AipsError("tHDF5Iterator - "
                         "cubeCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("three non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -321,7 +321,7 @@ void test8ElemROIter (const Lattice<Int>& lattice, Bool useRef)
         Matrix<Int> temp(iter.matrixCursor());
         throw(AipsError("tHDF5Iterator - "
                         "matrixCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("two non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -330,7 +330,7 @@ void test8ElemROIter (const Lattice<Int>& lattice, Bool useRef)
         Cube<Int> temp(iter.cubeCursor());
         throw(AipsError("tHDF5Iterator - "
                         "cubeCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("three non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -625,7 +625,7 @@ void testVectorRWIter (Lattice<Int>& lattice, Bool useRef)
         Matrix<Int> temp(iter.matrixCursor());
         throw(AipsError("tHDF5Iterator - "
                         "matrixCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("two non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -634,7 +634,7 @@ void testVectorRWIter (Lattice<Int>& lattice, Bool useRef)
         Cube<Int> temp(iter.cubeCursor());
         throw(AipsError("tHDF5Iterator - "
                         "cubeCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("three non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -693,7 +693,7 @@ void testMatrixRWIter (Lattice<Int>& lattice, Bool useRef)
         Vector<Int> temp(iter.vectorCursor());
         throw(AipsError("tHDF5Iterator - "
                         "vectorCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("one non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -702,7 +702,7 @@ void testMatrixRWIter (Lattice<Int>& lattice, Bool useRef)
         Cube<Int> temp(iter.cubeCursor());
         throw(AipsError("tHDF5Iterator - "
                         "cubeCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("three non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -758,7 +758,7 @@ void testCubeRWIter (Lattice<Int>& lattice, Bool useRef)
         Vector<Int> temp(iter.vectorCursor());
         throw(AipsError("tHDF5Iterator - "
                         "vectorCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("one non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -767,7 +767,7 @@ void testCubeRWIter (Lattice<Int>& lattice, Bool useRef)
         Matrix<Int> temp(iter.matrixCursor());
         throw(AipsError("tHDF5Iterator - "
                         "matrixCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("two non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -817,7 +817,7 @@ void testArrayRWIter (Lattice<Int>& lattice, Bool useRef)
         Vector<Int> temp(iter.vectorCursor());
         throw(AipsError("tHDF5Iterator - "
                         "vectorCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("one non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -826,7 +826,7 @@ void testArrayRWIter (Lattice<Int>& lattice, Bool useRef)
         Matrix<Int> temp(iter.matrixCursor());
         throw(AipsError("tHDF5Iterator - "
                         "matrixCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("two non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -835,7 +835,7 @@ void testArrayRWIter (Lattice<Int>& lattice, Bool useRef)
         Cube<Int> temp(iter.cubeCursor());
         throw(AipsError("tHDF5Iterator - "
                         "cubeCursor worked where it should not have"));
-    } catch (AipsError x) {
+    } catch (AipsError& x) {
         if (!x.getMesg().contains("three non-degenerate")) {
 	    throw (AipsError (x.getMesg()));
         }
@@ -1276,7 +1276,7 @@ int main (int argc, const char *argv[])
       pagedArr.put (savarr);
       testNonCongruentRWIter (pagedArr, True);
     }
-  } catch (AipsError x) {
+  } catch (AipsError& x) {
     cerr << "Caught exception: " << x.getMesg() << endl;
     cout << "FAIL" << endl;
     return 1;
@@ -1446,7 +1446,7 @@ int main (int argc, const char *argv[])
       testAdd (latArr1, pagedArr2, True);
       AlwaysAssert (allEQ(latArr1.get(), 13*arr), AipsError);
     }      
-  } catch (AipsError x) {
+  } catch (AipsError& x) {
     cerr << "Caught exception: " << x.getMesg() << endl;
     cout << "FAIL" << endl;
     return 1;
