@@ -330,7 +330,7 @@ int main ()
     }
     cout << "OK" << endl;
     return 0;
-  } catch   (AipsError x) {
+  } catch   (AipsError& x) {
     cerr << x.getMesg() << endl;
     cout << "FAIL" << endl;
     return 1;
