@@ -30,16 +30,17 @@
 
 //# Includes
 #include <casacore/casa/aips.h>
-#include<casacore/meas/MeasUDF/PositionEngine.h>
-#include <casacore/tables/TaQL/ExprNode.h>
+#include<casacore/meas/MeasUDF/MeasEngine.h>
 #include <casacore/measures/Measures/MEpoch.h>
 #include <casacore/measures/Measures/MCEpoch.h>
 #include <casacore/measures/Measures/MeasConvert.h>
-#include <casacore/measures/TableMeasures/ScalarMeasColumn.h>
-#include <casacore/measures/TableMeasures/ArrayMeasColumn.h>
 
 namespace casacore {
 
+  //# Forward declarations
+  class PositionEngine;
+
+  
 // <summary>
 // Engine for TaQL UDF Epoch conversions
 // </summary>
@@ -86,34 +87,17 @@ namespace casacore {
 // It makes it possible to handle measures in TaQL.
 // </motivation>
 
-  class EpochEngine
+  class EpochEngine: public MeasEngine<MEpoch>
   {
   public:
     EpochEngine();
 
-    // Get the reference type.
-    MEpoch::Types refType() const
-      { return itsRefType; } 
+    virtual ~EpochEngine();
 
     // Tell if the fraction has to be used for sidereal times.
     Bool sidFrac() const
       { return itsSidFrac; }
 
-    // Get the shape.
-    const IPosition& shape() const
-      { return itsShape; }
-
-    // Get the dimensionality.
-    Int ndim() const
-      { return itsNDim; }
-
-    // Tell if the expression is constant.
-    Bool isConstant() const;
-
-    // Get the unit.
-    const Unit& unit() const
-      { return itsUnit; }  
-
     // Get the values.
     Array<Double> getArrayDouble (const TableExprId& id);
 
@@ -122,15 +106,9 @@ namespace casacore {
 
     // Handle the argument(s) giving the input epochs and reference type.
     // The epoch can be a column in a table.
-    void handleEpoch (PtrBlock<TableExprNodeRep*>& args,
+    void handleEpoch (std::vector<TENShPtr>& args,
                       uInt& argnr);
 
-    // Handle a epoch reference type.
-    // If the reference type is invalid, an exception is only thrown
-    // if <src>doThrow=True</src>. In this way a string argument can
-    // be an observatory name for a position.
-    Bool handleEpochType (TableExprNodeRep* operand, Bool doThrow);
-
     // Set the MeasConvert object.
     void setConverter (MEpoch::Types toType, Bool sidFrac);
 
@@ -139,21 +117,16 @@ namespace casacore {
     void setPositionEngine (PositionEngine& engine);
 
   private:
-    void handleEpochArray (TableExprNodeRep* operand);
-    void handleConstant (TableExprNodeRep* operand);
+    // Strip a possible prefix from the epoch type.
+    virtual String stripMeasType (const String& type);
+    virtual void handleValues (TableExprNode& operand,
+                               const TableExprId& id,
+                               Array<MEpoch>& epochs);
 
-    //# Data members.
-    IPosition                   itsShape;
-    Int                         itsNDim;
-    Unit                        itsUnit;
+  //# Data members.
     Bool                        itsSidFrac;    //# T = fraction for sidereal 
     MeasFrame                   itsFrame;      //# frame used by converter
     MEpoch::Convert             itsConverter;
-    Vector<MEpoch>              itsConstants;
-    MEpoch::Types               itsRefType;
-    TableExprNode               itsExprNode;
-    ScalarMeasColumn<MEpoch>    itsMeasScaCol;
-    ArrayMeasColumn<MEpoch>     itsMeasArrCol;
     PositionEngine*             itsPositionEngine;
   };
 
