@@ -86,11 +86,11 @@ uInt MCuvw::ToRef_p[N_Routes][3] = {
   {Muvw::ICRS,			Muvw::J2000,	0},
   {Muvw::J2000,			Muvw::ICRS,	0} };
 uInt MCuvw::FromTo_p[Muvw::N_Types][Muvw::N_Types];
-MutexedInit MCuvw::theirMutexedInit (MCuvw::doFillState);
+CallOnce0 MCuvw::theirInitOnce;
 
 //# Constructors
 MCuvw::MCuvw() : measMath() {
-    fillState();
+    theirInitOnce(doFillState);
 }
 
 //# Destructor
@@ -649,13 +649,13 @@ void MCuvw::doConvert(MVuvw &in,
 }
 
 String MCuvw::showState() {
-  fillState();
+  theirInitOnce(doFillState);
   return MCBase::showState(MCuvw::FromTo_p[0],
 			   Muvw::N_Types, MCuvw::N_Routes,
 			   MCuvw::ToRef_p);
 }
 
-void MCuvw::doFillState (void*) {
+void MCuvw::doFillState() {
   Muvw::checkMyTypes();
   MCBase::makeState(FromTo_p[0], Muvw::N_Types, N_Routes, ToRef_p);
 }
