@@ -146,7 +146,7 @@ int main() {
 
     }
 
-  } catch (AipsError x) {
+  } catch (AipsError& x) {
     cout << x.getMesg() << endl;
   } 
   
