@@ -346,7 +346,7 @@ void testMain (Bool doExcep)
       try {
 	// test TMRefDesc no such column
 	TableMeasRefDesc tCol(td, "SillyColumnName");
-      } catch (AipsError x) {
+      } catch (AipsError& x) {
 	cout << "The following should report no such column ";
 	cout << " for TableMeasRefDesc.\n";
 	cout << x.getMesg() << endl;
@@ -354,7 +354,7 @@ void testMain (Bool doExcep)
       try {
 	// test TMRefDesc - column exist but is of the wrong type
 	TableMeasRefDesc tCol(td, "Time4ScaOffset");
-      } catch (AipsError x) {
+      } catch (AipsError& x) {
 	cout << "The following should report that the column's ";
 	cout << "type is no good.\n";
 	cout << x.getMesg() << endl;
@@ -362,7 +362,7 @@ void testMain (Bool doExcep)
       try {
 	// test TableMeasValueDesc - column doesn't exist exception
 	TableMeasValueDesc tCol(td, "SillyColumnName");
-      } catch (AipsError x) {
+      } catch (AipsError& x) {
 	cout << "The following should report no such column ";
 	cout << "for TableMeasValueDesc.\n";
 	cout << x.getMesg() << endl;
@@ -370,7 +370,7 @@ void testMain (Bool doExcep)
       try {
 	// test TableMeasValueDesc - column exists but not array
 	TableMeasValueDesc tCol(td, "Time4StrRef");
-      } catch (AipsError x) {
+      } catch (AipsError& x) {
 	cout << "The following should report that the column ";
 	cout << "is not array for TabelMeasValueDesc.\n";
 	cout << x.getMesg() << endl;
@@ -378,7 +378,7 @@ void testMain (Bool doExcep)
       try {
 	// test TableMeasValueDesc - column exists but is double
 	TableMeasValueDesc tCol(td, "Time2ArrRef");
-      } catch (AipsError x) {
+      } catch (AipsError& x) {
 	cout << "The following should report that the column's ";
 	cout << "type should be double for the TableMeasValueDesc.\n";
 	cout << x.getMesg() << endl;
@@ -388,7 +388,7 @@ void testMain (Bool doExcep)
 	Vector<Unit> u(2);
 	TableMeasValueDesc tCol(td, "Time2Arr");
 	TableMeasDesc<MEpoch> tmp(tCol, u);
-      } catch (AipsError x) {
+      } catch (AipsError& x) {
 	cout << "The following should report that the column's ";
 	cout << "unit vector is too long.\n";
 	cout << x.getMesg() << endl;
@@ -399,7 +399,7 @@ void testMain (Bool doExcep)
 	u(0) = "m";
 	TableMeasValueDesc tCol(td, "Time2Arr");
 	TableMeasDesc<MEpoch> tmp(tCol, u);
-      } catch (AipsError x) {
+      } catch (AipsError& x) {
 	cout << "The following should report that the column ";
 	cout << "has an invalid unit.\n";
 	cout << x.getMesg() << endl;
@@ -420,7 +420,7 @@ void testMain (Bool doExcep)
       try {
 	// get getOffset on a variable offset column
 	tmOsDesc.getOffset();
-      } catch (AipsError x) {
+      } catch (AipsError& x) {
 	cout << "Attempt to reference undefined Measure offset ";
 	cout << " exception on the TableMeasOffsetDesc object.\n";
 	cout << x.getMesg() << endl;
@@ -578,7 +578,7 @@ void testMain (Bool doExcep)
       if (doExcep) {
 	try {
 	  arrayCol.setDescUnits (u);
-	} catch (AipsError x) {
+	} catch (AipsError& x) {
 	  cout << "The following line should report an error ";
 	  cout << "in ScalarMeasColumn::setDescUnits - invalid unit.\n";
 	  cout << x.getMesg() << endl;
@@ -648,7 +648,7 @@ void testMain (Bool doExcep)
       try {
 	// try constructing with a non MeasureColumn
 	MEpoch::ScalarColumn tScaCol(tab, "TimeRef");
-      } catch (AipsError x) {
+      } catch (AipsError& x) {
 	cout << "The following line should report an error ";
 	cout << "in reconstruct - invalid column exception.\n";
 	cout << x.getMesg() << endl;
@@ -657,7 +657,7 @@ void testMain (Bool doExcep)
 	// test throw if null exception
 	MEpoch::ScalarColumn nullCol;
 	nullCol.throwIfNull();
-      } catch (AipsError x) {
+      } catch (AipsError& x) {
 	cout << "The following line should be a ";
 	cout << "null column exception.\n";
 	cout << x.getMesg() << endl;
@@ -666,7 +666,7 @@ void testMain (Bool doExcep)
 	// try constructing a ScalarMeasColumn with an Array Offset
 	// column
 	MEpoch::ScalarColumn(tab, "SpareCol1");
-      } catch (AipsError x) {
+      } catch (AipsError& x) {
 	cout << "The following line should be an illegal ";
 	cout << "offset column type exception.\n";
 	cout << x.getMesg() << endl;
@@ -840,7 +840,7 @@ void testMain (Bool doExcep)
 	MeasFrame frame(epoch_frame);
 	me.getRefPtr()->set(frame);
 	meCol.put(0, me);
-      } catch (AipsError x) {
+      } catch (AipsError& x) {
 	cout << "The following line should report an error ";
 	cout << "in ScalarMeasColumn::put - not allowed to put a ";
 	cout << "measure with a frame in variable column.\n";
@@ -943,7 +943,7 @@ void testMain (Bool doExcep)
       try {
 	Vector<Unit> u(1);
 	arrayCol.setDescUnits (u);
-      } catch (AipsError x) {
+      } catch (AipsError& x) {
 	cout << "The following line should report an error ";
 	cout << "in ScalarMeasColumn::setDescUnits - not allowed to put ";
 	cout << "when the table is not empty.\n";
@@ -1036,7 +1036,7 @@ void testMain (Bool doExcep)
 	// test throw if null exception
 	MEpoch::ArrayColumn nullCol;
 	nullCol.throwIfNull();
-      } catch (AipsError x) {
+      } catch (AipsError& x) {
 	cout << "The following line should be a ";
 	cout << "null column exception.\n";
 	cout << x.getMesg() << endl;
@@ -1105,14 +1105,14 @@ void testMain (Bool doExcep)
       Bool excp = False;
       try {
 	arrayCol.setDescRefCode (MEpoch::TAI);
-      } catch (AipsError) {
+      } catch (AipsError&) {
 	excp = True;
       }
       AlwaysAssertExit (excp);
       excp = False;
       try {
 	arrayCol.setDescOffset (obsTime);
-      } catch (AipsError) {
+      } catch (AipsError&) {
 	excp = True;
       }
       AlwaysAssertExit (excp);
@@ -1122,7 +1122,7 @@ void testMain (Bool doExcep)
       try {
 	Array<MEpoch> badShapeArr(IPosition(2,2));
 	scaStrRefCol.get(0, badShapeArr, False);
-      } catch (AipsError x) {
+      } catch (AipsError& x) {
 	cout << "The following line should be a ";
 	cout << "Table array conformance error exception.\n";
 	cout << x.getMesg() << endl;
@@ -1437,7 +1437,7 @@ int main(int argc, const char*[])
     // Do tests where a refcode changes.
     testRefCodeChg();
     cout << "Test completed normally...bye.\n";
-  } catch (AipsError x) {
+  } catch (AipsError& x) {
     cout << "An error occurred.  The test ended early with the following";
     cout << " message:\n";
     cout << x.getMesg() << endl;
