@@ -280,8 +280,8 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
     Vector<Int> feed1List=thisSelection.getFeed1List();
     Vector<Int> feed2List=thisSelection.getFeed2List();
     Vector<Int> feedPairList=thisSelection.getFeedPairList();
-    OrderedMap<Int, Vector<Int > > polMap=thisSelection.getPolMap();
-    OrderedMap<Int, Vector<Vector<Int> > > corrMap=thisSelection.getCorrMap();
+    std::map<Int, Vector<Int > > polMap=thisSelection.getPolMap();
+    std::map<Int, Vector<Vector<Int> > > corrMap=thisSelection.getCorrMap();
     Vector<Int> allDDIDList;
     if (ddIDList.nelements() == 0) allDDIDList = spwDDIDList;
     else if (spwDDIDList.nelements() == 0) allDDIDList = ddIDList;
