@@ -316,10 +316,6 @@ public:
   // to the first plane of the cube returned by this method
   const Cube<Double>& receptorAngles() const;
 
-  // Return the channel number of the first channel in the DATA.
-  // (non-zero for reference MS created by VisSet with channel selection)
-  Int startChan() const;
-
   // Return a string mount identifier for each antenna
   const Vector<String>& antennaMounts() const;
 
@@ -395,17 +391,14 @@ protected:
   Int curPolarizationId_p, lastPolarizationId_p;
   Int curDataDescId_p, lastDataDescId_p;
   Bool more_p, newMS_p, newArray_p, newField_p, newSpectralWindow_p, 
-    newPolarizationId_p, newDataDescId_p, preselected_p,
+    newPolarizationId_p, newDataDescId_p, 
     timeDepFeed_p, spwDepFeed_p, checkFeed_p;
-  Int startChan_p;
 
   // Globally control disk storage of SORTED_TABLE
   Bool storeSorted_p;
 
   // time selection
   Double interval_p;
-  // channel selection
-  Block<Int> preselectedChanStart_p,preselectednChan_p;
   
   // columns
   ScalarColumn<Int> colArray_p, colDataDesc_p, colField_p;
@@ -475,7 +468,6 @@ inline const Vector<String>& MSIter::antennaMounts() const
 {return antennaMounts_p;}
 inline const Cube<RigidVector<Double, 2> >& MSIter::getBeamOffsets() const
 {return beamOffsets_p;}
-inline Int MSIter::startChan() const {return startChan_p;}
 inline Bool MSIter::allBeamOffsetsZero() const {return allBeamOffsetsZero_p;}
 
 } //# NAMESPACE CASACORE - END
