@@ -314,7 +314,7 @@ int main()
       run_nearest_tests<Double,Float>();
 
   }
-  catch (AipsError x) {
+  catch (AipsError& x) {
     cerr << x.getMesg() << endl;
     cout << "FAIL" << endl;
     return 1;
