@@ -47,8 +47,8 @@ ISMColumn::ISMColumn (ISMBase* parent, int dataType, uInt colnr)
   fixedLength_p (0),
   colnr_p       (colnr),
   nrelem_p      (1),
-  startRow_p    (-1),
-  endRow_p      (-1),
+  startRow_p    (1),
+  endRow_p      (0),
   lastValue_p   (0),
   lastRowPut_p  (0)
 {
@@ -83,6 +83,9 @@ void ISMColumn::clear()
     case TpUInt:
 	delete [] (uInt*)lastValue_p;
 	break;
+    case TpInt64:
+	delete [] (Int64*)lastValue_p;
+	break;
     case TpFloat:
 	delete [] (float*)lastValue_p;
 	break;
@@ -143,8 +146,8 @@ void ISMColumn::remove (uInt bucketRownr, ISMBucket* bucket, uInt bucketNrrow,
     uInt& nused = bucket->indexUsed (colnr_p);
     // Invalidate the last value read.
     columnCache().invalidate();
-    startRow_p = -1;
-    endRow_p   = -1;
+    startRow_p = 1;
+    endRow_p   = 0;
     // We have to change the bucket, so let the cache set the dirty flag
     // for this bucket.
     stmanPtr_p->setBucketDirty();
@@ -174,79 +177,62 @@ void ISMColumn::remove (uInt bucketRownr, ISMBucket* bucket, uInt bucketNrrow,
 
 void ISMColumn::getBoolV (uInt rownr, Bool* value)
 {
-    if (isLastValueInvalid (rownr)) {
-	getValue (rownr, lastValue_p, True);
-    }
+    getValue (rownr, lastValue_p, True);
     *value = *(Bool*)lastValue_p;
 }
 void ISMColumn::getuCharV (uInt rownr, uChar* value)
 {
-    if (isLastValueInvalid (rownr)) {
-	getValue (rownr, lastValue_p, True);
-    }
+    getValue (rownr, lastValue_p, True);
     *value = *(uChar*)lastValue_p;
 }
 void ISMColumn::getShortV (uInt rownr, Short* value)
 {
-    if (isLastValueInvalid (rownr)) {
-	getValue (rownr, lastValue_p, True);
-    }
+    getValue (rownr, lastValue_p, True);
     *value = *(Short*)lastValue_p;
 }
 void ISMColumn::getuShortV (uInt rownr, uShort* value)
 {
-    if (isLastValueInvalid (rownr)) {
-	getValue (rownr, lastValue_p, True);
-    }
+    getValue (rownr, lastValue_p, True);
     *value = *(uShort*)lastValue_p;
 }
 void ISMColumn::getIntV (uInt rownr, Int* value)
 {
-    if (isLastValueInvalid (rownr)) {
-	getValue (rownr, lastValue_p, True);
-    }
+    getValue (rownr, lastValue_p, True);
     *value = *(Int*)lastValue_p;
 }
 void ISMColumn::getuIntV (uInt rownr, uInt* value)
 {
-    if (isLastValueInvalid (rownr)) {
-	getValue (rownr, lastValue_p, True);
-    }
+    getValue (rownr, lastValue_p, True);
     *value = *(uInt*)lastValue_p;
 }
+void ISMColumn::getInt64V (uInt rownr, Int64* value)
+{
+    getValue (rownr, lastValue_p, True);
+    *value = *(Int64*)lastValue_p;
+}
 void ISMColumn::getfloatV (uInt rownr, float* value)
 {
-    if (isLastValueInvalid (rownr)) {
-	getValue (rownr, lastValue_p, True);
-    }
+    getValue (rownr, lastValue_p, True);
     *value = *(float*)lastValue_p;
 }
 void ISMColumn::getdoubleV (uInt rownr, double* value)
 {
-    if (isLastValueInvalid (rownr)) {
-	getValue (rownr, lastValue_p, True);
-    }
+    getValue (rownr, lastValue_p, True);
     *value = *(double*)lastValue_p;
 }
 void ISMColumn::getComplexV (uInt rownr, Complex* value)
 {
-    if (isLastValueInvalid (rownr)) {
-	getValue (rownr, lastValue_p, True);
-    }
+    getValue (rownr, lastValue_p, True);
     *value = *(Complex*)lastValue_p;
 }
 void ISMColumn::getDComplexV (uInt rownr, DComplex* value)
 {
-    if (isLastValueInvalid (rownr)) {
-	getValue (rownr, lastValue_p, True);
-    }
+    getValue (rownr, lastValue_p, True);
     *value = *(DComplex*)lastValue_p;
 }
 void ISMColumn::getStringV (uInt rownr, String* value)
 {
-    if (isLastValueInvalid (rownr)) {
-	getValue (rownr, lastValue_p, True);
-    }
+    getValue (rownr, lastValue_p, True);
     *value = *(String*)lastValue_p;
 }
 
@@ -256,7 +242,7 @@ void ISMColumn::getScalarColumnBoolV (Vector<Bool>* dataPtr)
     uInt rownr = 0;
     while (rownr < nrrow) {
 	getBoolV (rownr, &((*dataPtr)(rownr)));
-	for (rownr++; Int(rownr)<=endRow_p; rownr++) {
+	for (rownr++; rownr<=endRow_p; rownr++) {
 	    (*dataPtr)(rownr) = *(Bool*)lastValue_p;
 	}
     }
@@ -267,7 +253,7 @@ void ISMColumn::getScalarColumnuCharV (Vector<uChar>* dataPtr)
     uInt rownr = 0;
     while (rownr < nrrow) {
 	getuCharV (rownr, &((*dataPtr)(rownr)));
-	for (rownr++; Int(rownr)<=endRow_p; rownr++) {
+	for (rownr++; rownr<=endRow_p; rownr++) {
 	    (*dataPtr)(rownr) = *(uChar*)lastValue_p;
 	}
     }
@@ -278,7 +264,7 @@ void ISMColumn::getScalarColumnShortV (Vector<Short>* dataPtr)
     uInt rownr = 0;
     while (rownr < nrrow) {
 	getShortV (rownr, &((*dataPtr)(rownr)));
-	for (rownr++; Int(rownr)<=endRow_p; rownr++) {
+	for (rownr++; rownr<=endRow_p; rownr++) {
 	    (*dataPtr)(rownr) = *(Short*)lastValue_p;
 	}
     }
@@ -289,7 +275,7 @@ void ISMColumn::getScalarColumnuShortV (Vector<uShort>* dataPtr)
     uInt rownr = 0;
     while (rownr < nrrow) {
 	getuShortV (rownr, &((*dataPtr)(rownr)));
-	for (rownr++; Int(rownr)<=endRow_p; rownr++) {
+	for (rownr++; rownr<=endRow_p; rownr++) {
 	    (*dataPtr)(rownr) = *(uShort*)lastValue_p;
 	}
     }
@@ -300,7 +286,7 @@ void ISMColumn::getScalarColumnIntV (Vector<Int>* dataPtr)
     uInt rownr = 0;
     while (rownr < nrrow) {
 	getIntV (rownr, &((*dataPtr)(rownr)));
-	for (rownr++; Int(rownr)<=endRow_p; rownr++) {
+	for (rownr++; rownr<=endRow_p; rownr++) {
 	    (*dataPtr)(rownr) = *(Int*)lastValue_p;
 	}
     }
@@ -311,11 +297,22 @@ void ISMColumn::getScalarColumnuIntV (Vector<uInt>* dataPtr)
     uInt rownr = 0;
     while (rownr < nrrow) {
 	getuIntV (rownr, &((*dataPtr)(rownr)));
-	for (rownr++; Int(rownr)<=endRow_p; rownr++) {
+	for (rownr++; rownr<=endRow_p; rownr++) {
 	    (*dataPtr)(rownr) = *(uInt*)lastValue_p;
 	}
     }
 }
+void ISMColumn::getScalarColumnInt64V (Vector<Int64>* dataPtr)
+{
+    uInt nrrow = dataPtr->nelements();
+    uInt rownr = 0;
+    while (rownr < nrrow) {
+	getInt64V (rownr, &((*dataPtr)(rownr)));
+	for (rownr++; rownr<=endRow_p; rownr++) {
+	    (*dataPtr)(rownr) = *(Int64*)lastValue_p;
+	}
+    }
+}
 void ISMColumn::getScalarColumnfloatV (Vector<float>* dataPtr)
 {
     //# Note: using getStorage/putStorage is about 3 times faster
@@ -324,7 +321,7 @@ void ISMColumn::getScalarColumnfloatV (Vector<float>* dataPtr)
     uInt rownr = 0;
     while (rownr < nrrow) {
 	getfloatV (rownr, &((*dataPtr)(rownr)));
-	for (rownr++; Int(rownr)<=endRow_p; rownr++) {
+	for (rownr++; rownr<=endRow_p; rownr++) {
 	    (*dataPtr)(rownr) = *(float*)lastValue_p;
 	}
     }
@@ -335,7 +332,7 @@ void ISMColumn::getScalarColumndoubleV (Vector<double>* dataPtr)
     uInt rownr = 0;
     while (rownr < nrrow) {
 	getdoubleV (rownr, &((*dataPtr)(rownr)));
-	for (rownr++; Int(rownr)<=endRow_p; rownr++) {
+	for (rownr++; rownr<=endRow_p; rownr++) {
 	    (*dataPtr)(rownr) = *(double*)lastValue_p;
 	}
     }
@@ -346,7 +343,7 @@ void ISMColumn::getScalarColumnComplexV (Vector<Complex>* dataPtr)
     uInt rownr = 0;
     while (rownr < nrrow) {
 	getComplexV (rownr, &((*dataPtr)(rownr)));
-	for (rownr++; Int(rownr)<=endRow_p; rownr++) {
+	for (rownr++; rownr<=endRow_p; rownr++) {
 	    (*dataPtr)(rownr) = *(Complex*)lastValue_p;
 	}
     }
@@ -357,7 +354,7 @@ void ISMColumn::getScalarColumnDComplexV (Vector<DComplex>* dataPtr)
     uInt rownr = 0;
     while (rownr < nrrow) {
 	getDComplexV (rownr, &((*dataPtr)(rownr)));
-	for (rownr++; Int(rownr)<=endRow_p; rownr++) {
+	for (rownr++; rownr<=endRow_p; rownr++) {
 	    (*dataPtr)(rownr) = *(DComplex*)lastValue_p;
 	}
     }
@@ -368,7 +365,7 @@ void ISMColumn::getScalarColumnStringV (Vector<String>* dataPtr)
     uInt rownr = 0;
     while (rownr < nrrow) {
 	getStringV (rownr, &((*dataPtr)(rownr)));
-	for (rownr++; Int(rownr)<=endRow_p; rownr++) {
+	for (rownr++; rownr<=endRow_p; rownr++) {
 	    (*dataPtr)(rownr) = *(String*)lastValue_p;
 	}
     }
@@ -382,7 +379,6 @@ void ISMColumn::aips_name2(getScalarColumnCells,NM) \
     Bool delV; \
     T* value = values->getStorage (delV); \
     T* valptr = value; \
-    const ColumnCache& cache = columnCache(); \
     if (rownrs.isSliced()) { \
         RefRowsSliceIter iter(rownrs); \
         while (! iter.pastEnd()) { \
@@ -390,12 +386,13 @@ void ISMColumn::aips_name2(getScalarColumnCells,NM) \
             uInt end = iter.sliceEnd(); \
             uInt incr = iter.sliceIncr(); \
             while (rownr <= end) { \
-                if (rownr < cache.start()  ||  rownr > cache.end()) { \
+                if (isLastValueInvalid (rownr)) { \
                     aips_name2(get,NM) (rownr, valptr); \
-                    DebugAssert (cache.incr() == 0, AipsError); \
+                    valptr++; \
+                    rownr += incr; \
                 } \
-                const T* cacheValue = (const T*)(cache.dataPtr()); \
-                uInt endrow = min (end, cache.end()); \
+                const T* cacheValue = (const T*)(lastValue_p); \
+                uInt endrow = min (end, endRow_p); \
                 while (rownr <= endrow) { \
 	            *valptr++ = *cacheValue; \
                     rownr += incr; \
@@ -409,22 +406,21 @@ void ISMColumn::aips_name2(getScalarColumnCells,NM) \
         if (nr > 0) { \
             Bool delR; \
             const uInt* rows = rowvec.getStorage (delR); \
-            if (rows[0] < cache.start()  ||  rows[0] > cache.end()) { \
+            if (isLastValueInvalid (rows[0])) { \
                 aips_name2(get,NM) (0, &(value[0])); \
             } \
-            const T* cacheValue = (const T*)(cache.dataPtr()); \
-            uInt strow = cache.start(); \
-            uInt endrow = cache.end(); \
-            AlwaysAssert (cache.incr() == 0, AipsError); \
+            const T* cacheValue = (const T*)(lastValue_p); \
+            uInt strow = startRow_p; \
+            uInt endrow = endRow_p; \
             for (uInt i=0; i<nr; i++) { \
 	        uInt rownr = rows[i]; \
                 if (rownr >= strow  &&  rownr <= endrow) { \
 	            value[i] = *cacheValue; \
 	        } else { \
 	            aips_name2(get,NM) (rownr, &(value[i])); \
-                    cacheValue = (const T*)(cache.dataPtr()); \
-                    strow = cache.start(); \
-                    endrow = cache.end(); \
+                    cacheValue = (const T*)(lastValue_p);      \
+                    strow = startRow_p;                 \
+                    endrow = endRow_p;                   \
 	        } \
 	    } \
             rowvec.freeStorage (rows, delR); \
@@ -438,6 +434,7 @@ ISMCOLUMN_GET(Short,ShortV)
 ISMCOLUMN_GET(uShort,uShortV)
 ISMCOLUMN_GET(Int,IntV)
 ISMCOLUMN_GET(uInt,uIntV)
+ISMCOLUMN_GET(Int64,Int64V)
 ISMCOLUMN_GET(float,floatV)
 ISMCOLUMN_GET(double,doubleV)
 ISMCOLUMN_GET(Complex,ComplexV)
@@ -446,6 +443,7 @@ ISMCOLUMN_GET(String,StringV)
 
 void ISMColumn::getValue (uInt rownr, void* value, Bool setCache)
 {
+  if (rownr < startRow_p  ||  rownr > endRow_p) {
     // Get the bucket with its row number boundaries.
     uInt bucketStartRow, bucketNrrow;
     ISMBucket* bucket = stmanPtr_p->getBucket (rownr, bucketStartRow,
@@ -459,9 +457,10 @@ void ISMColumn::getValue (uInt rownr, void* value, Bool setCache)
     readFunc_p (value, bucket->get (offset), nrcopy_p);
     startRow_p = bucketStartRow + stint;
     endRow_p   = bucketStartRow + endint;
-    if (setCache) {
-	columnCache().set (startRow_p, endRow_p, lastValue_p);
-    }
+  }
+  if (setCache) {
+    columnCache().set (startRow_p, endRow_p, lastValue_p);
+  }
 }
 
 void ISMColumn::putBoolV (uInt rownr, const Bool* value)
@@ -484,6 +483,10 @@ void ISMColumn::putIntV (uInt rownr, const Int* value)
 {
     putValue (rownr, value);
 }
+void ISMColumn::putInt64V (uInt rownr, const Int64* value)
+{
+    putValue (rownr, value);
+}
 void ISMColumn::putuIntV (uInt rownr, const uInt* value)
 {
     putValue (rownr, value);
@@ -551,6 +554,13 @@ void ISMColumn::putScalarColumnuIntV (const Vector<uInt>* dataPtr)
 	putValue (i, &((*dataPtr)(i)));
     }
 }
+void ISMColumn::putScalarColumnInt64V (const Vector<Int64>* dataPtr)
+{
+    uInt nrrow = dataPtr->nelements();
+    for (uInt i=0; i<nrrow; i++) {
+	putValue (i, &((*dataPtr)(i)));
+    }
+}
 void ISMColumn::putScalarColumnfloatV (const Vector<float>* dataPtr)
 {
     uInt nrrow = dataPtr->nelements();
@@ -589,9 +599,7 @@ void ISMColumn::putScalarColumnStringV (const Vector<String>* dataPtr)
 
 void ISMColumn::getArrayBoolV (uInt rownr, Array<Bool>* value)
 {
-    if (isLastValueInvalid (rownr)) {
-	getValue (rownr, lastValue_p, False);
-    }
+    getValue (rownr, lastValue_p, False);
     *value = Array<Bool> (shape_p, (Bool*)lastValue_p, SHARE);
 }
 
@@ -604,9 +612,7 @@ void ISMColumn::putArrayBoolV (uInt rownr, const Array<Bool>* value)
 }
 void ISMColumn::getArrayuCharV (uInt rownr, Array<uChar>* value)
 {
-    if (isLastValueInvalid (rownr)) {
-	getValue (rownr, lastValue_p, False);
-    }
+    getValue (rownr, lastValue_p, False);
     *value = Array<uChar> (shape_p, (uChar*)lastValue_p, SHARE);
 }
 
@@ -619,9 +625,7 @@ void ISMColumn::putArrayuCharV (uInt rownr, const Array<uChar>* value)
 }
 void ISMColumn::getArrayShortV (uInt rownr, Array<Short>* value)
 {
-    if (isLastValueInvalid (rownr)) {
-	getValue (rownr, lastValue_p, False);
-    }
+    getValue (rownr, lastValue_p, False);
     *value = Array<Short> (shape_p, (Short*)lastValue_p, SHARE);
 }
 
@@ -634,9 +638,7 @@ void ISMColumn::putArrayShortV (uInt rownr, const Array<Short>* value)
 }
 void ISMColumn::getArrayuShortV (uInt rownr, Array<uShort>* value)
 {
-    if (isLastValueInvalid (rownr)) {
-	getValue (rownr, lastValue_p, False);
-    }
+    getValue (rownr, lastValue_p, False);
     *value = Array<uShort> (shape_p, (uShort*)lastValue_p, SHARE);
 }
 
@@ -649,9 +651,7 @@ void ISMColumn::putArrayuShortV (uInt rownr, const Array<uShort>* value)
 }
 void ISMColumn::getArrayIntV (uInt rownr, Array<Int>* value)
 {
-    if (isLastValueInvalid (rownr)) {
-	getValue (rownr, lastValue_p, False);
-    }
+    getValue (rownr, lastValue_p, False);
     *value = Array<Int> (shape_p, (Int*)lastValue_p, SHARE);
 }
 
@@ -664,9 +664,7 @@ void ISMColumn::putArrayIntV (uInt rownr, const Array<Int>* value)
 }
 void ISMColumn::getArrayuIntV (uInt rownr, Array<uInt>* value)
 {
-    if (isLastValueInvalid (rownr)) {
-	getValue (rownr, lastValue_p, False);
-    }
+    getValue (rownr, lastValue_p, False);
     *value = Array<uInt> (shape_p, (uInt*)lastValue_p, SHARE);
 }
 
@@ -677,11 +675,22 @@ void ISMColumn::putArrayuIntV (uInt rownr, const Array<uInt>* value)
     putValue (rownr, data);
     value->freeStorage (data, deleteIt);
 }
+void ISMColumn::getArrayInt64V (uInt rownr, Array<Int64>* value)
+{
+    getValue (rownr, lastValue_p, False);
+    *value = Array<Int64> (shape_p, (Int64*)lastValue_p, SHARE);
+}
+
+void ISMColumn::putArrayInt64V (uInt rownr, const Array<Int64>* value)
+{
+    Bool deleteIt;
+    const Int64* data = value->getStorage (deleteIt);
+    putValue (rownr, data);
+    value->freeStorage (data, deleteIt);
+}
 void ISMColumn::getArrayfloatV (uInt rownr, Array<float>* value)
 {
-    if (isLastValueInvalid (rownr)) {
-	getValue (rownr, lastValue_p, False);
-    }
+    getValue (rownr, lastValue_p, False);
     *value = Array<float> (shape_p, (float*)lastValue_p, SHARE);
 }
 
@@ -694,9 +703,7 @@ void ISMColumn::putArrayfloatV (uInt rownr, const Array<float>* value)
 }
 void ISMColumn::getArraydoubleV (uInt rownr, Array<double>* value)
 {
-    if (isLastValueInvalid (rownr)) {
-	getValue (rownr, lastValue_p, False);
-    }
+    getValue (rownr, lastValue_p, False);
     *value = Array<double> (shape_p, (double*)lastValue_p, SHARE);
 }
 
@@ -709,9 +716,7 @@ void ISMColumn::putArraydoubleV (uInt rownr, const Array<double>* value)
 }
 void ISMColumn::getArrayComplexV (uInt rownr, Array<Complex>* value)
 {
-    if (isLastValueInvalid (rownr)) {
-	getValue (rownr, lastValue_p, False);
-    }
+    getValue (rownr, lastValue_p, False);
     *value = Array<Complex> (shape_p, (Complex*)lastValue_p, SHARE);
 }
 
@@ -724,9 +729,7 @@ void ISMColumn::putArrayComplexV (uInt rownr, const Array<Complex>* value)
 }
 void ISMColumn::getArrayDComplexV (uInt rownr, Array<DComplex>* value)
 {
-    if (isLastValueInvalid (rownr)) {
-	getValue (rownr, lastValue_p, False);
-    }
+    getValue (rownr, lastValue_p, False);
     *value = Array<DComplex> (shape_p, (DComplex*)lastValue_p, SHARE);
 }
 
@@ -739,9 +742,7 @@ void ISMColumn::putArrayDComplexV (uInt rownr, const Array<DComplex>* value)
 }
 void ISMColumn::getArrayStringV (uInt rownr, Array<String>* value)
 {
-    if (isLastValueInvalid (rownr)) {
-	getValue (rownr, lastValue_p, False);
-    }
+    getValue (rownr, lastValue_p, False);
     *value = Array<String> (shape_p, (String*)lastValue_p, SHARE);
 }
 
@@ -791,8 +792,8 @@ void ISMColumn::putValue (uInt rownr, const void* value)
     }
     // Invalidate the last value read.
     columnCache().invalidate();
-    startRow_p = -1;
-    endRow_p   = -1;
+    startRow_p = 1;
+    endRow_p   = 0;
     // Exit if new value equals current value.
     readFunc_p (lastValue_p, bucket->get (offset), nrcopy_p);
     if (compareValue (value, lastValue_p)) {
@@ -1226,6 +1227,14 @@ void ISMColumn::init()
 	    objset ((uInt*)lastValue_p, undef, nrelem_p);
 	}
 	break;
+    case TpInt64:
+	{
+	    compareFunc_p = ObjCompare<Int64>::compare;
+	    lastValue_p   = new Int64 [nrelem_p];
+	    Int64 undef = 0;
+	    objset ((Int64*)lastValue_p, undef, nrelem_p);
+	}
+	break;
     case TpFloat:
 	{
 	    compareFunc_p = ObjCompare<float>::compare;
@@ -1300,8 +1309,8 @@ void ISMColumn::resync (uInt nrrow)
 {
     // Invalidate the last value read.
     columnCache().invalidate();
-    startRow_p   = -1;
-    endRow_p     = -1;
+    startRow_p   = 1;
+    endRow_p     = 0;
     lastRowPut_p = nrrow;
 }
 void ISMColumn::reopenRW()
